bufiox

package
v1.99.0-pre Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 5, 2026 License: BSD-3-Clause Imports: 1 Imported by: 0

Documentation

Overview

Package bufiox provides extensions to the standard bufio package.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ReadFull

func ReadFull(r BufferedReader, buf []byte) (int, error)

ReadFull reads exactly len(buf) bytes from r into buf, like io.ReadFull, but without heap allocations. It uses Peek to access the buffered data directly, copies it into buf, then discards the consumed bytes. If an error occurs, discard is not called and the buffer is left unchanged.

Types

type BufferedReader

type BufferedReader interface {
	Peek(n int) ([]byte, error)
	Discard(n int) (discarded int, err error)
}

BufferedReader is an interface for readers that support peeking into an internal buffer, like bufio.Reader.

Jump to